document.addEventListener("DOMContentLoaded", function() {
    console.log("DOM content loaded");
    fetchNumQuestionsAndStart(); // Fetch questions based on URL parameters
    startTimer();
    fetchUserIdFromSession();
    fetchTestId();
    document.getElementById('goToDashboardButton').addEventListener('click', function() {
        window.location.href = '/dashboard';
    });

    document.getElementById('viewTestResultsButton').addEventListener('click', function() {
        window.location.href = `/user-test-results/${user_id}/${testId}`;
    });
});

var timePerQuestion = [];
var currentQuestionIndex = 0;
var userResponses = [];
var optionLetters = ['A', 'B', 'C', 'D'];
var questionsData;
var user_id;
var testId;
var currentQuestionStartTime = Date.now();
var selectedOptionIndex = null;
// Function Declarations
function fetchQuestions(numQuestions) {
    const generateTestUrl = `/generate-test/${numQuestions}`;
    fetch(generateTestUrl)
        .then(response => {
            if (!response.ok) {
                throw new Error('Network response was not ok');
            }
            return response.json();
        })
        .then(data => {
            questionsData = data;
            console.log('Questions Data:', questionsData);

            // Start rendering questions using a for-loop
            for (var i = 0; i < (numQuestions - 1); i++) {
                renderQuestion(i);
            }
        })
        .catch(error => console.error('Error fetching questions:', error));
}

function fetchNumQuestionsAndStart() {
    // Get the 'numQuestions' parameter from the URL
    const urlParams = new URLSearchParams(window.location.search);
    const numQuestions = urlParams.get('numQuestions');

    if (numQuestions) {
        fetchQuestions(numQuestions);
    } else {
        console.error('Invalid number of questions parameter in URL.');
    }
}

function fetchUserIdFromSession() {
    // Make a GET request to a server endpoint that returns the session data
    fetch('/get-user-id', {
        method: 'GET',
        credentials: 'include',  // Include credentials (cookies) in the request
    })
    .then(response => response.json())
    .then(data => {
        // Check if 'user_id' is available in the session data
        if (data.user_id !== undefined) {
            user_id = data.user_id;
            console.log('User ID:', user_id);

            // You can use 'user_id' as needed in your client-side code here
        } else {
            console.error('User is not authenticated or session data is missing.');
        }
    })
    .catch(error => console.error('Error fetching user session data:', error));
}

function renderQuestion(index) {
    var questionContainer = document.querySelector('#questions-container .question');
    var optionsContainer = document.querySelector('#questions-container .options');
    if (!questionContainer || !optionsContainer) {
        console.error("Question or options container not found.");
        return;
    }

    var currentQuestion = questionsData[index];
    if (!currentQuestion) {
        console.error("No question found at index", index);
        return;
    }

    questionContainer.textContent = currentQuestion.text;

    // Clear previous options
    optionsContainer.innerHTML = '';

    // Iterate over each answer and create a button
    currentQuestion.answers.forEach(function(answer, optionIndex) {
        var optionElement = document.createElement('button');
        optionElement.className = 'option-button';
        optionElement.textContent = answer;
        optionElement.setAttribute('data-index', optionIndex);

        // Check if this option was previously selected and update the class
        if (userResponses[index] && userResponses[index].includes(optionIndex)) {
            optionElement.classList.add('selected');
        }

        // Attach an event listener to handle selection
        optionElement.addEventListener('click', function() {
            selectOption(optionIndex); // Pass optionIndex as an argument
        });

        optionsContainer.appendChild(optionElement);
    });
}

function selectOption(optionIndex) {
    console.log("Received option index:", optionIndex);

    // Update the global selectedOptionIndex variable
    selectedOptionIndex = optionIndex;

    var optionButton = document.querySelectorAll('.option-button')[optionIndex];
    optionButton.classList.add('selected');

    // Calculate the time spent on the current question
    var timeSpentOnQuestion = calculateTimePerQuestion();

    var currentQuestion = questionsData[currentQuestionIndex];
    userResponses[currentQuestionIndex] = {
        question_id: currentQuestion.id,
        user_response: optionLetters[optionIndex],
        domain: currentQuestion.domain,
        time_per_question: timeSpentOnQuestion
    };

    console.log("Option selected:", optionLetters[optionIndex]);
    console.log("Current User Responses:", userResponses);

    // If it's the last question, you might want to handle the end of the test here
    if (currentQuestionIndex === questionsData.length - 1) {
        // Optionally, prompt the user to submit or call submitTest() directly
        if (confirm("You have answered the last question. Do you want to submit the test now?")) {
        }
    }

    // Reset the start time for the next question
    currentQuestionStartTime = Date.now();
}

function updateResponses(userResponse) {
    // Ensure there's an array to store responses for the current question
    if (!userResponses[currentQuestionIndex]) {
        userResponses[currentQuestionIndex] = [];
    }

    var currentResponses = userResponses[currentQuestionIndex];
    var responseIndex = currentResponses.indexOf(userResponse);

    if (responseIndex === -1) {
        // Add the selected user response if not already in the array
        currentResponses.push(userResponse);
    } else {
        // Remove the user response if it's already in the array
        currentResponses.splice(responseIndex, 1);
    }
}

function previousQuestion() {
    if (currentQuestionIndex > 0) {
        currentQuestionIndex--;
        renderQuestion(currentQuestionIndex);
    }
}

function nextQuestion() {
    var correctAnswerMessage = document.getElementById('correctAnswer');
    if (correctAnswerMessage) {
        correctAnswerMessage.textContent = '';
    }

    // Check if a response has been recorded for the current question
    if (!userResponses[currentQuestionIndex]) {
        alert("Please select an option before proceeding to the next question.");
        return;
    }

    // Proceed to the next question or handle the end of the test
    if (currentQuestionIndex < questionsData.length - 1) {
        // If it's not the last question, proceed to the next question
        currentQuestionIndex++;
        renderQuestion(currentQuestionIndex);
        currentQuestionStartTime = Date.now(); // Reset start time for the next question
    } else {
        // If it's the last question, handle the test completion
        console.log("Current User Responses:", userResponses);
        if (confirm("You have finished the Test. Please use the 'Submit' button to turn in your test.")) {
            submitTest(); // Consider automatically submitting the test
        }
    }
}

function calculateTimePerQuestion() {
    var currentTime = Date.now();
    var timeSpent = (currentTime - currentQuestionStartTime) / 1000; // Time spent in seconds
    return timeSpent;
}

function retryTest() {
    console.log("Retrying test");
    currentQuestionIndex = 0;
    renderQuestion(currentQuestionIndex);
}

function getCurrentQuestionId() {
    return questionsData[currentQuestionIndex].id;
}

function showAnswer() {
    var currentQuestionId = getCurrentQuestionId();
    fetch(`/show-answer/${currentQuestionId}`)
        .then(response => response.text())
        .then(data => {
            var correctAnswerElement = document.getElementById('correctAnswer');
            correctAnswerElement.textContent = data;
            correctAnswerElement.classList.remove('hide');
            var showAnswerButton = document.getElementById('showAnswer');
            showAnswerButton.classList.add('hide');
        })
        .catch(error => console.error("Error fetching correct answer:", error));
}

async function fetchTestId() {
    let response = await fetch('/get-test-id');
    let data = await response.json();
    console.log('Retrieved test id:', data.test_id);
    testId = data.test_id;
    return testId;
}

function checkCorrectAnswers(userResponses, questionsData) {
    return userResponses.map(response => {
        const question = questionsData.find(q => q.id === response.question_id);
        return {
            ...response,
            is_correct: question && response.user_response === question.correct_answer
        };
    });
}

async function submitTest() {
    console.log('User Responses:', userResponses);

    // Capture the last response if the test is complete
    if (currentQuestionIndex === questionsData.length - 1 && selectedOptionIndex !== null) {
        updateTimePerQuestion(selectedOptionIndex); // Ensure the last question's time is updated
    }

    // Check if all questions have been answered
    if (userResponses.length !== questionsData.length) {
        alert('Please answer all questions before submitting the test.');
        return;
    }

    // Process the responses to include all necessary information
    var processedResponses = userResponses.map(response => {
        const question = questionsData.find(q => q.id === response.question_id);
        return {
            question_id: response.question_id,
            is_correct: question && response.user_response === question.correct_answer ? 'Correct' : 'Incorrect',
            domain: question.domain,
            time_per_question: response.time_per_question, // Use the time from userResponses
            letters_user_chosen: response.user_response
        };
    });

    var testId = await fetchTestId(); // Make sure this function returns the test ID correctly

    var score = calculateScore(processedResponses.filter(r => r.is_correct === 'Correct').length, questionsData.length);
    var timerValue = document.getElementById('time').textContent;

    var requestData = {
        user_id: user_id, // Assume user_id is globally available or fetched earlier
        test_id: testId, // Use the fetched test ID
        questions: processedResponses,
        timer: timerValue, // This assumes you have an element with id='time' which has the overall test time
        total_questions: questionsData.length,
        score: score,
    };

    // Submit the test data to the server
    console.log("Sending requestData:", requestData);
    fetch('/submit-test', {
        method: 'POST',
        headers: { 'Content-Type': 'application/json' },
        body: JSON.stringify(requestData),
    })
    .then(response => response.json())
    .then(data => {
        console.log('Success:', data);
        document.getElementById('submit').classList.add('hide');
        document.getElementById('goToDashboardButton').classList.remove('hide');
        document.getElementById('viewTestResultsButton').classList.remove('hide');
    })
    .catch((error) => console.error('Error:', error));
}

function checkCorrectAnswers(userResponses, questionsData) {
    var correctAnswers = 0;
    userResponses.forEach(function(response, index) {
        if (response.user_response === questionsData[index].correct_answer) {
            correctAnswers++;
        }
    });
    return correctAnswers;
}

function updateTimer() {
    var currentTime = Math.floor((Date.now() - startTime) / 1000);
    var minutes = Math.floor(currentTime / 60);
    var seconds = currentTime % 60;
    var formattedTime = `${minutes < 10 ? '0' : ''}${minutes}:${seconds < 10 ? '0' : ''}${seconds}`;
    document.getElementById('time').textContent = formattedTime;
}

function startTimer() {
    startTime = Date.now();
    updateTimer();
    timerInterval = setInterval(updateTimer, 1000);
}

function calculateScore(correctAnswers, totalQuestions) {
    var percentage = (correctAnswers / totalQuestions) * 100;
    return Math.round(percentage);
}

function updateTimePerQuestion() {
    var timeSpentOnQuestion = calculateTimePerQuestion();
    if (currentQuestionIndex < questionsData.length) {
        var currentQuestion = questionsData[currentQuestionIndex];
        userResponses[currentQuestionIndex] = {
            question_id: currentQuestion.id,
            user_response: optionLetters[selectedOptionIndex],
            domain: currentQuestion.domain,
            time_per_question: timeSpentOnQuestion
        };
    }
}