document.addEventListener('DOMContentLoaded', function() {
    // Call fetchUserIdFromSession when the page loads
    fetchUserIdFromSession();
});

function startTest() {
    var numQuestions = prompt("Please enter the number of questions for the test (minimum 5):", "5");
    numQuestions = parseInt(numQuestions); // Convert to integer

    if (!Number.isNaN(numQuestions) && Number.isInteger(numQuestions) && numQuestions >= 5) {
        window.location.href = `/test-page?numQuestions=${numQuestions}`;
    } else if (numQuestions === null) {
        alert("Test creation canceled.");
    } else {
        alert("Please enter a valid integer greater than or equal to 5.");
    }
}
var user_id;

function fetchUserIdFromSession() {
    // Make a GET request to a server endpoint that returns the session data
    fetch('/get-user-id', {
        method: 'GET',
        credentials: 'include',  // Include credentials (cookies) in the request
    })
    .then(response => response.json())
    .then(data => {
        // Check if 'user_id' is available in the session data
        if (data.user_id !== undefined) {
            user_id = data.user_id;
            console.log('User ID:', user_id);

            // Fetch user data using 'user_id'
            fetchUserData(user_id);
        } else {
            console.error('User is not authenticated or session data is missing.');
        }
    })
    .catch(error => console.error('Error fetching user session data:', error));
}

function fetchUserData(user_Id) {
    console.log(user_Id);
    const apiUrl = `/api/user-data/${user_Id}`; // Adjust the URL as needed

    // Make a GET request to the API endpoint
    fetch(apiUrl)
        .then(response => {
            if (!response.ok) {
                throw new Error('Network response was not ok');
            }
            return response.json();
        })
        .then(data => {
            // Creating a UserData object with the response data
            const userData = {
                first_name: data.first_name,
                last_name: data.last_name,
                last_login: data.last_login,
                total_tests_taken: data.total_tests_taken,
                average_score: data.average_score,
                last_test_date: data.last_test_date
            };
            updateUserUI(userData);
            console.log(userData);
        })
        .catch(error => {
            // Handle errors that occurred during the fetch request
            console.error('Fetch error:', error);
        });
}

function updateUserUI(userData) {
    // Update the UI with the user data
    document.getElementById('firstName').textContent = userData.first_name;
    document.getElementById('lastName').textContent = userData.last_name;

    // Format and display the last login date with the prefix "Last login: "
    if (userData.last_login) {
        let loginDate = new Date(userData.last_login);
        let formattedLoginDate = loginDate.toLocaleDateString(); // Formats the date as per local setting
        document.getElementById('lastLogin').textContent = "Last login: " + formattedLoginDate;
    } else {
        document.getElementById('lastLogin').textContent = "Last login: No data"; // Placeholder text for no date
    }

    document.getElementById('totalTestsTaken').textContent = userData.total_tests_taken;

    // Check if 'average_score' is null
    if (userData.average_score === null) {
        document.getElementById('averageScore').textContent = "N/A"; // Set a placeholder text
    } else {
        document.getElementById('averageScore').textContent = userData.average_score;
    }

    // Format and display only the date part for 'last_test_date'
    if (userData.last_test_date) {
        let date = new Date(userData.last_test_date);
        let formattedDate = date.toLocaleDateString(); // Formats the date as per local setting
        document.getElementById('lastTestDate').textContent = formattedDate;
    } else {
        document.getElementById('lastTestDate').textContent = "No data"; // Placeholder text for no date
    }
}
function viewResults() {
    if (user_id !== undefined) {
        window.location.href = `/view-past-tests/${user_id}`;
    } else {
        alert("User not authenticated or user ID not available.");
    }
}

function updateProfile() {
    // Redirect to the update profile page
    window.location.href = '/update-profile-form';
}

function TrainingPlan() {
    window.location.href = '/training-plan';
}

