var user_id;
var users = [];

document.addEventListener('DOMContentLoaded', () => {
    fetchUserData();
    fetchUserIdFromSession();
    document.getElementById('newUserForm').addEventListener('submit', submitNewUserForm);
});

function fetchUserIdFromSession() {
    // Make a GET request to a server endpoint that returns the session data
    fetch('/get-user-id', {
        method: 'GET',
        credentials: 'include',  // Include credentials (cookies) in the request
    })
    .then(response => response.json())
    .then(data => {
        // Check if 'user_id' is available in the session data
        if (data.user_id !== undefined) {
            user_id = data.user_id;
            console.log('User ID:', user_id);

            // Fetch user data using 'user_id'
            fetchUserData(user_id);
        } else {
            console.error('User is not authenticated or session data is missing.');
        }
    })
    .catch(error => console.error('Error fetching user session data:', error));
}

function fetchUserData() {
    fetch('/api/users', {
        credentials: 'include'
    })
    .then(response => response.json())
    .then(data => {
        users = data; // Store user data globally
        displayUsers(1); // Initial display for page 1
        setupPagination(users.length);
    })
    .catch(error => console.error('Error fetching users:', error));
}

function displayUsers(page) {
    const perPage = 10;
    const start = (page - 1) * perPage;
    const end = start + perPage;
    const pageUsers = users.slice(start, end);

    const tbody = document.getElementById('users-tbody');
    tbody.innerHTML = '';  // Clear existing content
    pageUsers.forEach((user, index) => {
        const tr = document.createElement('tr');
        tr.innerHTML = `
            <td>${start + index + 1}</td>
            <td>${user.username}</td>
            <td>${user.Name}</td>
            <td>${user.last_login ? new Date(user.last_login).toLocaleString() : 'Never'}</td>
            <td>${user.role}</td>
            <td>${user.status}</td>
            <td>
                <a href="#" class="settings" title="Settings" data-toggle="tooltip"><i class="material-icons">&#xE8B8;</i></a>
                <a href="#" class="delete" title="Delete" data-toggle="tooltip"><i class="material-icons">&#xE5C9;</i></a>
            </td>
        `;
        tbody.appendChild(tr);
    });
    document.getElementById('current-entries').textContent = `${start + 1}-${end > users.length ? users.length : end}`;
    document.getElementById('total-entries').textContent = users.length;
}

function setupPagination(totalEntries) {
    const perPage = 10;
    const pageCount = Math.ceil(totalEntries / perPage);
    const pagination = document.getElementById('pagination-controls');
    pagination.innerHTML = ''; // Clear existing pagination controls

    const prevLi = document.createElement('li');
    prevLi.className = 'page-item';
    prevLi.innerHTML = '<a href="#" class="page-link">Previous</a>';
    prevLi.onclick = () => {
        const currentPage = parseInt(document.querySelector('.pagination .active a').textContent);
        if (currentPage > 1) displayUsers(currentPage - 1);
    };
    pagination.appendChild(prevLi);

    for (let i = 1; i <= pageCount; i++) {
        const li = document.createElement('li');
        li.className = `page-item ${i === 1 ? 'active' : ''}`;
        li.innerHTML = `<a href="#" class="page-link">${i}</a>`;
        li.addEventListener('click', () => {
            document.querySelector('.pagination .active').classList.remove('active');
            li.classList.add('active');
            displayUsers(i);
        });
        pagination.appendChild(li);
    }

    const nextLi = document.createElement('li');
    nextLi.className = 'page-item';
    nextLi.innerHTML = '<a href="#" class="page-link">Next</a>';
    nextLi.onclick = () => {
        const currentPage = parseInt(document.querySelector('.pagination .active a').textContent);
        if (currentPage < pageCount) displayUsers(currentPage + 1);
    };
    pagination.appendChild(nextLi);
}

function submitNewUserForm(event) {
    event.preventDefault();
    const form = event.target;
    const formData = new FormData(form);

    fetch('/create-user', {
        method: 'POST',
        body: formData,
    })
    .then(response => {
        if (response.ok) {
            $('#addUserModal').modal('hide');
            return response.json();
        } else {
            throw new Error('Failed to create user. Server responded with status ' + response.status);
        }
    })
    .then(data => {
        console.log('User created successfully:', data);
        fetchUserData();
    })
    .catch(error => {
        console.error('Error:', error);
        alert("Failed to create user: " + error.message);
    });
}