var projectId;
document.addEventListener('DOMContentLoaded', function() {
    let currentSlide = 0;
    const slides = document.querySelectorAll('.slide');
    projectId = getProjectIdFromUrl();

    function showSlide(index) {
    slides.forEach((slide, i) => {
        slide.classList.remove('active');
        if (i === index) {
            slide.classList.add('active');

            // Check the slide ID and fetch data accordingly
            if (slide.id === 'internal-audit-findings') {
                fetchAuditFindings(projectId);
            } else if (slide.id === 'risk-assessment-findings') { // Make sure this ID matches your Page 5 slide
                fetchRiskAssessmentData(projectId);
            }
        }
    });
}

    document.getElementById('prev').addEventListener('click', function() {
        currentSlide = (currentSlide > 0) ? currentSlide - 1 : slides.length - 1;
        showSlide(currentSlide);
    });

    document.getElementById('next').addEventListener('click', function() {
        currentSlide = (currentSlide < slides.length - 1) ? currentSlide + 1 : 0;
        showSlide(currentSlide);
    });

    // Initialize the slideshow
    showSlide(currentSlide);
    fetchUserId();
    fetchAndSetCustomerAndDate(projectId);
    fetchAndSetComplianceType();
});

function getProjectIdFromUrl() {
    const pathname = window.location.pathname;
    const segments = pathname.split('/'); // Split the URL path by '/'

    // Assuming the project_id is always the last segment of the URL
    const projectId = segments.pop() || segments.pop();  // Handle potential trailing slash

    return projectId;
}
function fetchAuditFindings(projectId) {
    fetch(`/api/non-conformities/${projectId}`)
        .then(response => response.json())
        .then(data => {
            populateAuditFindingsTable(data);
        })
        .catch(error => console.error('Error fetching audit findings:', error));
}

function populateAuditFindingsTable(findings) {
    const tableBody = document.getElementById('audit-findings-body');
    tableBody.innerHTML = ''; // Clear existing rows

    findings.forEach(finding => {
        const row = tableBody.insertRow();

        // Assuming 'control_id' is the topic
        const topicCell = row.insertCell();
        topicCell.textContent = finding.control_id;

        // 'Non-Conformity' as the finding
        const findingCell = row.insertCell();
        findingCell.textContent = finding['Non-Conformity'];

        // Placeholder for 'Remediation Plan' or use 'notes'
        const remediationPlanCell = row.insertCell();
        remediationPlanCell.textContent = 'To be updated...'; // Or finding.notes if you want to use the notes here

        // Optionally, if you want to include 'notes' as additional information, add another column in your HTML and here in JS
        // const notesCell = row.insertCell();
        // notesCell.textContent = finding.notes;
    });
}


function fetchRiskAssessmentData(projectId) {
    fetch(`/api/fetch-risk-assessment-data?projectId=${projectId}`)
        .then(response => response.json())
        .then(data => {
            populateRiskAssessmentTable(data);
        })
        .catch(error => console.error('Error fetching risk assessment data:', error));
}

function populateRiskAssessmentTable(risks) {
    const tableBody = document.getElementById('risk-assesment-body'); // Ensure the ID matches your HTML
    tableBody.innerHTML = ''; // Clear existing rows

    risks.forEach(risk => {
        const row = tableBody.insertRow();

        row.insertCell().textContent = risk.record_no; // No.
        row.insertCell().textContent = risk.asset_name; // Name of Asset/Threat-based Analysis
        row.insertCell().textContent = risk.risk_owner; // Risk Owner
        row.insertCell().textContent = risk.threat; // Threat
        row.insertCell().textContent = risk.vulnerability; // Vulnerability
        row.insertCell().textContent = risk.impact; // Impact
        row.insertCell().textContent = risk.probability; // Probability
        row.insertCell().textContent = risk.risk; // Risk
        row.insertCell().textContent = risk.treatment_options; // Risk treatment options
        row.insertCell().textContent = risk.security_controls; // Annex A - Security Controls
        row.insertCell().textContent = risk.implementation_technique !== 'undefined' ? risk.implementation_technique : 'N/A'; // Implementation Technique
    });
}

function fetchAndSetComplianceType() {
    console.log(projectId); // Log the projectId to confirm its value and type

    fetch('/api/compliance-projects/')
        .then(response => response.json())
        .then(data => {
            // Convert both projectId values to the same type (e.g., number) before comparing
            const matchingProject = data.find(project => Number(project.projectId) === Number(projectId));

            // If a matching project is found, set the complianceType
            if (matchingProject) {
                const complianceType = matchingProject.complianceType;
                document.getElementById('compliance_type').textContent = complianceType;
            } else {
                console.error('No matching project found for the given projectId:', projectId);
            }
        })
        .catch(error => console.error('Error fetching compliance type:', error));
}


function fetchAndSetCustomerAndDate(projectId) {
    fetch(`/fetch-ra-rtp-data?projectId=${projectId}`) // Confirm the URL is correct
        .then(response => response.json())
        .then(data => {
            const customerName = data.customer_name; // Use the correct property name from your response
            const dateOfSubmission = data.date_of_submission; // Use the correct property name from your response

            // Update all elements with the 'customer_name' class
            document.querySelectorAll('.customer_name').forEach(element => {
                element.textContent = customerName;
            });

            // Update all elements with the 'date' class
            document.querySelectorAll('.date').forEach(element => {
                element.textContent = dateOfSubmission;
            });
        })
        .catch(error => console.error('Error fetching customer and date:', error));
}

function updateCustomerName(customerName) {
    const elements = document.querySelectorAll('.customer_name'); // Select all elements with the 'customer_name' class

    elements.forEach(element => {
        element.textContent = customerName; // Set the text content for each element
    });
}

function fetchAndSetUserName(userId) {
    fetch(`/api/user-data/${userId}`) // Ensure the URL is correct
        .then(response => response.json())
        .then(data => {
            const firstName = data.first_name; // Adjust based on your response structure
            const lastName = data.last_name; // Adjust based on your response structure
            document.querySelector('span#user_name').textContent = `${firstName} ${lastName}`;
        })
        .catch(error => console.error('Error fetching user data:', error));
}

function fetchUserId() {
    fetch('/get-user-id')
        .then(response => response.json()) // Assuming the response is JSON
        .then(data => {
            const userId = data.user_id; // Accessing 'user_id' as per your JSON structure
            // Now you can use userId in other functions that require it
            console.log("Fetched User ID:", userId);
            fetchAndSetUserName(userId);
        })
        .catch(error => console.error('Error fetching user ID:', error));
}