var completed_Chapters = [], inprogress_Chapters = [], notstarted_Chapters = [], compliant = 0, partially_compliant = 0, havent_started = 0, not_applicable = 0, not_compliant = 0;
var projectID, complianceType ,totalControls;
var completedChapters , notstartedChapters , inprogressChapters;

document.addEventListener('DOMContentLoaded', function() {
    const urlParams = new URLSearchParams(window.location.search);
    projectID = urlParams.get('project_id');
    complianceType = urlParams.get('complianceType');

    // Initialize charts here to ensure they are set up when the page loads
    initializeCharts();
    if (projectID) {
        fetchProjectDashboardData(projectID);
    } else {
        console.error('Project ID not found in URL parameters');
    }

    if (complianceType) {
        fetchComplianceDetails(complianceType);
    } else {
        console.error('complianceType not found in URL parameters');
    }
});

function fetchData(projectID) {
    console.log("Fetching data for project ID:", projectID);
    return fetch('/project-dashboard-view/' + projectID) // Fetching data
    .then(response => {
        if (!response.ok) {
            throw new Error('Network response was not ok');
        }
        return response.json(); // Parsing JSON
    })
    .then(data => {
        processComplianceData(data);
        return data; // Return the processed data for further use
    })
    .catch(error => {
        console.error('There has been a problem with your fetch operation:', error);
    });
}

function processComplianceData(data) {
    console.log("Processing compliance data:", data);
    // Reset counts
    compliant = 0, partially_compliant = 0, not_compliant = 0, not_applicable = 0, havent_started = 0;

    // Count each status
    data.forEach(item => {
        switch(item.control_status) {
            case 'Compliant': compliant++; break;
            case 'Partially Compliant': partially_compliant++; break;
            case 'Non-Compliant': not_compliant++; break;
            case 'Not Applicable': not_applicable++; break;}
    });

    // Update global variables
    window.compliant = compliant;
    window.partially_compliant = partially_compliant;
    window.not_compliant = not_compliant;
    window.not_applicable = not_applicable;

    // Update HTML Elements
}

function fetchComplianceDetails(complianceType) {
    console.log("Fetching compliance details for type:", complianceType);
    fetch('/get-compliance-details/' + complianceType)
    .then(response => {
        if (!response.ok) {
            throw new Error('Network response was not ok');
        }
        return response.json();
    })
    .then(details => {
        let totalControls = 0;
        Object.keys(details).forEach(chapter => {
            totalControls += details[chapter].length;
        });

        // Now you have the total number of controls
        console.log("Total number of controls:", totalControls);

        // Process compliance details and update elements
        processComplianceDetails(details);
        updateHTMLElementsControls(totalControls);
    })
    .catch(error => {
        console.error('There has been a problem with your fetch operation:', error);
    });
}

function processComplianceDetails(details) {
    console.log("Processing compliance details:", details);
    var chapterControlsMap = {};

    // Loop through each chapter in the details
    for (let chapterName in details) {
        if (details.hasOwnProperty(chapterName)) {
            // Extracting control IDs for each chapter
            chapterControlsMap[chapterName] = new Set(
                details[chapterName].map(control => control.control_id)
            );
        }
    }

    console.log("Chapter Controls Map:", chapterControlsMap);

    // Assuming you have project data available to process chapters immediately
    fetchData(projectID).then(projectData => {
        console.log("About to call findChaptersProgress");
        findChaptersProgress(projectData, chapterControlsMap);
    });
}

function fetchProjectDashboardData(projectID) {
    console.log("Fetching project dashboard data for project ID:", projectID);
    fetchData(projectID);
}

function findChaptersProgress(projectData, chapterControlsMap) {
    if (!Array.isArray(projectData)) {
        console.error('Invalid project data:', projectData);
        return; // Exit the function if projectData is not an array
    }
    console.log("Finding chapters progress");
    console.log("Project Data:", projectData);
    console.log("Chapter Controls Map:", chapterControlsMap);
    completedChapters = [];
    inprogressChapters = [];
    notstartedChapters = [];

    for (let chapter in chapterControlsMap) {
        let chapterControls = chapterControlsMap[chapter];
        let compliantCount = 0;

        chapterControls.forEach(control_id => {
            if (projectData.some(item => item.control_id === control_id && item.control_status === 'Compliant')) {
                compliantCount++;
            }
        });

        if (compliantCount === chapterControls.size) {
            completedChapters.push(chapter);
        } else if (compliantCount > 0) {
            inprogressChapters.push(chapter);
        } else {
            notstartedChapters.push(chapter);
        }
    }

    // Update global variables
    window.completedChapters = completedChapters;
    window.inprogressChapters = inprogressChapters;
    window.notstartedChapters = notstartedChapters;

    updateHTMLElementsChapters()
    updateChaptersChart();
    console.log("Completed Chapters:", completedChapters);
    console.log("In-Progress Chapters:", inprogressChapters);
    console.log("Not-Started Chapters:", notstartedChapters);

}

function updateHTMLElementsChapters() {
    console.log("Updating HTML elements for chapters");
    console.log("Completed Chapters:", window.completedChapters.length);
    console.log("In-Progress Chapters:", window.inprogressChapters.length);
    console.log("Not-Started Chapters:", window.notstartedChapters.length);

    // Update text elements
    var completedChaptersElement = document.getElementById('completedChapters');
    if (completedChaptersElement) {
        completedChaptersElement.innerText = 'Completed Chapters: ' + (window.completedChapters ? window.completedChapters.length : 0);
    }

    var inprogressChaptersElement = document.getElementById('inprogressChapters');
    if (inprogressChaptersElement) {
        inprogressChaptersElement.innerText = 'In-Progress Chapters: ' + (window.inprogressChapters ? window.inprogressChapters.length : 0);
    }

    var notstartedChaptersElement = document.getElementById('notstartedChapters');
    if (notstartedChaptersElement) {
        notstartedChaptersElement.innerText = 'Not-Started Chapters: ' + (window.notstartedChapters ? window.notstartedChapters.length : 0);
    }

}

function updateHTMLElementsControls(totalControls) {
    // Calculate 'haven't started' based on the total number of controls
    window.havent_started = totalControls - (window.compliant + window.partially_compliant + window.not_compliant + window.not_applicable);
    havent_started = window.havent_started;
    console.log("Updating HTML elements for controls");
    console.log("Compliant:", window.compliant);
    console.log("Partially Compliant:", window.partially_compliant);
    console.log("Not Compliant:", window.not_compliant);
    console.log("Not Applicable:", window.not_applicable);
    console.log("Haven't Started:", window.havent_started);

    document.getElementById('compliant').innerText = 'Compliant: ' + window.compliant;
    document.getElementById('partiallyCompliant').innerText = 'Partially Compliant: ' + window.partially_compliant;
    document.getElementById('notCompliant').innerText = 'Not Compliant: ' + window.not_compliant;
    document.getElementById('notApplicable').innerText = 'Not Applicable: ' + window.not_applicable;
    document.getElementById('haventStarted').innerText = 'Havent Started: ' + window.havent_started;

    updateControlsChart();
}

// --------------Pie Dashboards-------------------------
function createPieChart(canvasId, data, backgroundColors) {
    return new Chart(document.getElementById(canvasId), {
        type: 'pie',
        data: {
            labels: data.labels,
            datasets: [{
                data: data.values,
                backgroundColor: backgroundColors
            }]
        },
        options: {
            responsive: false,
            maintainAspectRatio: true, // Maintain aspect ratio
            aspectRatio: 1 // You can adjust this value as needed
        }
    });
}

function updateChartData(chart, data) {
    chart.data.datasets[0].data = data;
    chart.update();
}
function initializeCharts() {
    // Initialize values for the charts with zeros
    var chaptersInitialData = {
        labels: ['Completed', 'In Progress', 'Not Started'],
        values: [0, 0, 0] // Zero initial values
    };

    var controlsInitialData = {
        labels: ['Compliant', 'Partially Compliant', 'Not Compliant', 'Not Applicable', 'Havent Started'],
        values: [0, 0, 0, 0, 0] // Zero initial values
    };

    // Create the charts with initial data
    window.chaptersChart = createPieChart('chaptersChart', chaptersInitialData, ['green', 'blue', 'orange']);
    window.controlsChart = createPieChart('controlsChart', controlsInitialData, ['green', 'blue', 'red', 'orange', 'grey']);
}
function updateChaptersChart() {
    if (window.chaptersChart) {
        console.log("Updating Chapters Chart with:", completedChapters.length, inprogressChapters.length, notstartedChapters.length);
        updateChartData(window.chaptersChart, [
            completedChapters.length,
            inprogressChapters.length,
            notstartedChapters.length
        ]);
    } else {
        console.error('Chapters chart not initialized');
    }
}

function updateControlsChart() {
    if (window.controlsChart) {
        console.log("Updating Controls Chart with:", window.compliant, window.partially_compliant, window.not_compliant, window.not_applicable, window.havent_started);
        updateChartData(window.controlsChart, [
            window.compliant,
            window.partially_compliant,
            window.not_compliant,
            window.not_applicable,
            window.havent_started
        ]);
    } else {
        console.error('Controls chart not initialized');
    }
}

