document.addEventListener('DOMContentLoaded', function () {
    const searchButton = document.querySelector('.btn-search');
    const searchInput = document.getElementById('search-input');
    const filterSelect = document.getElementById('filter');
    let isSearchBoxExpanded = false; // State to track search box expansion
    let clients = [];

    // Fetch clients data
    fetch('/api/clients')
        .then(response => response.json())
        .then(data => {
            clients = data;
        });

    // Event listener for search button click
    searchButton.addEventListener('click', function () {
        if (!isSearchBoxExpanded) {
            searchInput.style.width = '300px';
            searchInput.focus();
            this.textContent = ''; // Hide the 'SRC' text
            isSearchBoxExpanded = true;
        } else {
            searchInput.style.width = '50px';
            this.textContent = 'Src'; // Show the 'SRC' text
            isSearchBoxExpanded = false;
        }
    });

    // Event listener for search input blur (losing focus)
    searchInput.addEventListener('blur', function () {
        searchButton.textContent = 'Src'; // Show the 'SRC' text
        this.style.width = '50px';
        isSearchBoxExpanded = false;
    });

    // Event listener for the 'Enter' key in search input
    searchInput.addEventListener('keypress', function (e) {
        if (e.key === 'Enter') {
            const searchText = searchInput.value.toLowerCase();
            const filter = filterSelect.value;

            // Filter the clients
            const filteredClients = clients.filter(client => {
                switch (filter) {
                    case 'name':
                        return client.name.toLowerCase().includes(searchText);
                    case 'compliance':
                        return client.compliances && client.compliances.toLowerCase().includes(searchText);
                    default: // 'all'
                        return client.name.toLowerCase().includes(searchText) ||
                               (client.compliances && client.compliances.toLowerCase().includes(searchText));
                }
            });

            displayResults(filteredClients);
        }
    });

// Function to display results
function displayResults(filteredClients) {
    const resultsContainer = document.getElementById('search-results');
    resultsContainer.innerHTML = ''; // Clear existing results

    if (filteredClients.length === 0) {
        resultsContainer.innerHTML = '<p>No results found.</p>';
        return;
    }

    const table = document.createElement('table');
    const thead = document.createElement('thead');
    const tbody = document.createElement('tbody');

    // Create table header
    thead.innerHTML = '<tr><th>Name</th><th>Compliances</th><th>Other Details</th><th>Actions</th></tr>';
    table.appendChild(thead);

    // Populate table body
    filteredClients.forEach(client => {
        let complianceValue = client.compliances || 'SOC2';

        const tr = document.createElement('tr');
        tr.innerHTML = `<td>${client.name}</td>
                <td>${complianceValue}</td>
                <td>${client.preperation_phase || client.type || client.audit_record || ''}</td>
                <td><a href='/compliance-dashboard?customerId=${client.id}' class='action-link'>View</a> | <a href='#' class='action-link' onclick='exportClient("${client.id}")'>Export</a></td>`;
        tbody.appendChild(tr);
    });

    table.appendChild(tbody);
    resultsContainer.appendChild(table);
}


});

function exportClient(clientId) {
    alert("Under Maintenance");
    console.log("Export client with ID:", clientId);
    // Implement export logic here
}