document.addEventListener('DOMContentLoaded', function() {
    fetchUserIdFromSession();
});

var user_id;

function fetchUserIdFromSession() {
    fetch('/get-user-id', {
        method: 'GET',
        credentials: 'include'
    })
    .then(response => response.json())
    .then(data => {
        if (data.user_id !== undefined) {
            user_id = data.user_id;
            fetchComplianceProjects();
        } else {
            console.error('User is not authenticated or session data is missing.');
        }
    })
    .catch(error => console.error('Error fetching user session data:', error));
}

function fetchComplianceProjects() {
    // Assuming user_id is available globally. If not, fetch it as shown previously.
    fetch(`/api/compliance-projects/`)
        .then(response => response.json())
        .then(data => {
            populateComplianceProjectsTable(data);
        })
        .catch(error => console.error('Error fetching compliance projects:', error));
}

function populateComplianceProjectsTable(projectsData) {
    const tableBody = document.getElementById('compliance-projects-table').querySelector('tbody');
    tableBody.innerHTML = ''; // Clear existing data

    projectsData.forEach(project => {
        let row = tableBody.insertRow();
        row.insertCell().textContent = project.projectId;
        row.insertCell().textContent = project.projectName;
        row.insertCell().textContent = project.complianceType;
        row.insertCell().textContent = formatDate(project.startDate);
        row.insertCell().textContent = project.endDate ? formatDate(project.endDate) : 'N/A';
        row.insertCell().textContent = project.status;

        // Actions cell
        let actionsCell = row.insertCell();

        if (project.status === 'Active') {
            actionsCell.appendChild(createButton('Start Project', startProject, project.projectId, project.complianceType));
        } else if (project.status === 'In Progress' || project.status === 'Initiated') {
            if (project.status === 'Initiated') {
                actionsCell.appendChild(createButton('Manage', manageProject, project.projectId, project.complianceType));
                actionsCell.appendChild(document.createTextNode(' | ')); // Separator
                actionsCell.appendChild(createButton('Finish', finishProject, project.projectId, project.complianceType));
            } else {
                actionsCell.appendChild(createButton('Manage', manageProject, project.projectId, project.complianceType));
            }
        }
    });
}

function createButton(text, onClickFunction, projectId, complianceType) {
    let button = document.createElement('button');
    button.textContent = text;
    button.onclick = () => onClickFunction(projectId, complianceType);
    button.setAttribute('data-project-id', projectId);
    button.setAttribute('data-compliance-type', complianceType);
    return button;
}

function formatDate(dateString) {
    const options = { year: 'numeric', month: 'long', day: 'numeric' };
    return new Date(dateString).toLocaleDateString(undefined, options);
}

function finishProject(projectId) {
    fetch(`/finish-compliance-project/${projectId}`, {
        method: 'POST',
        credentials: 'include',
        headers: { 'Content-Type': 'application/json' }
    })
    .then(response => {
        if (!response.ok) {
            throw new Error('Failed to finish project');
        }
        return response.json();
    })
    .then(data => {
        console.log('Project finished successfully:', data);
        // Refresh the projects table or redirect as needed
    })
    .catch(error => console.error('Error finishing project:', error));
}

function manageProject(projectId, complianceType) {
    window.location.href = `/manage-compliance-project/${projectId}?complianceType=${complianceType}`;
}
